@@ -4,9 +4,9 @@ CrysPyEditor
 
 """
 name = "cryspy_editor"
-__version__ = "1.5.6"
-from cryspy_editor.main_window import main_w
+__version__ = "1.6.1"
 
+from cryspy_editor.__main__ import main
 
 if __name__ == "__main__":
-    main_w()
+    main()
